==> sellpath_test-0.0.18-py3-none-any.whl: sellpath_test/http_client.py <==
import requests


class SellPathHttpClient:
    def __init__(self, app_type, api_key):
        """
        Initialize the Client Manager with a specific tenant ID and available tools.
        """
        self.app_type = app_type
        self.api_key = api_key
        self.apollo_base_url = "https://api.apollo.io/v1"

    def __repr__(self):
        return "sellpath_http_client"

    @property
    def type(self):
        return "sellpath_http_client"

    def get(self, path, params={}):
        """
        Perform a GET request to the Apollo API.

        Args:
            path (str): API endpoint path.
            params (dict): Query parameters.

        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        """
        return self._apollo_http_request("get", path, params=params)

    def post(self, path, params={}, body={}):
        """
        Perform a POST request to the Apollo API.

        Args:
            path (str): API endpoint path.
            params (dict): Query parameters.
            body (dict): Request body.

        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        """
        return self._apollo_http_request("post", path, params=params, body=body)

    def patch(self, path, params={}, body={}):
        """
        Perform a PATCH request to the Apollo API.

        Args:
            path (str): API endpoint path.
            params (dict): Query parameters.
            body (dict): Request body.

        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        """
        return self._apollo_http_request("patch", path, params=params, body=body)

    def put(self, path, params={}, body={}):
        """
        Perform a PUT request to the Apollo API.

        Args:
            path (str): API endpoint path.
            params (dict): Query parameters.
            body (dict): Request body.

        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        """
        return self._apollo_http_request("put", path, params=params, body=body)

    def delete(self, path, params={}):
        """
        Perform a DELETE request to the Apollo API.

        Args:
            path (str): API endpoint path.
            params (dict): Query parameters.

        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        """
        return self._apollo_http_request("delete", path, params=params)

    def _apollo_http_request(self, method, path, params={}, body={}):
        """
        Perform an HTTP request to the Apollo API.

        Args:
            method (str): HTTP method (get, post, patch, put, delete).
            path (str): API endpoint path.
            params (dict): Query parameters.
            body (dict): Request body.
            raw (bool): Flag indicating whether to return raw response or JSON.
        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        Raises:
            Exception: If an invalid HTTP method is provided.
        """
        available_http_method = ["get", "post", "patch", "put", "delete"]
        method = method.lower()
        apollo_api_key = self.api_key
        if method not in available_http_method:
            raise Exception(f"not available method {method}")
        request_method = getattr(requests, method)

        base_url = self.apollo_base_url
        url = base_url + ("/" + path if not path.startswith("/") else path)

        if method.lower() == "get":
            params["api_key"] = apollo_api_key
            response = request_method(url, params=params)
        else:
            body["api_key"] = apollo_api_key
            response = request_method(url, params=params, json=body)
        # return response
        result = {}
        result["headers"] = response.headers
        result["status_code"] = response.status_code
        try:
            result["body"] = response.json()
        except Exception:
            result["body"] = response.content
        return result

==> sellpath_test-0.0.22-py3-none-any.whl: sellpath_test/http_client.py <==
import requests


class SellPathHttpClient:
    def __init__(self, app_type, api_key):
        """
        Initialize the Client Manager with a specific tenant ID and available tools.
        """
        self.app_type = app_type
        self.api_key = api_key
        self.apollo_base_url = "https://api.apollo.io/v1"

    def __repr__(self):
        return "sellpath_http_client"

    @property
    def type(self):
        return "sellpath_http_client"

    def get(self, path, params={}):
        """
        Perform a GET request to the Apollo API.

        Args:
            path (str): API endpoint path.
            params (dict): Query parameters.

        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        """
        return self._apollo_http_request("get", path, params=params)

    def post(self, path, params={}, body={}):
        """
        Perform a POST request to the Apollo API.

        Args:
            path (str): API endpoint path.
            params (dict): Query parameters.
            body (dict): Request body.

        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        """
        return self._apollo_http_request("post", path, params=params, body=body)

    def patch(self, path, params={}, body={}):
        """
        Perform a PATCH request to the Apollo API.

        Args:
            path (str): API endpoint path.
            params (dict): Query parameters.
            body (dict): Request body.

        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        """
        return self._apollo_http_request("patch", path, params=params, body=body)

    def put(self, path, params={}, body={}):
        """
        Perform a PUT request to the Apollo API.

        Args:
            path (str): API endpoint path.
            params (dict): Query parameters.
            body (dict): Request body.

        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        """
        return self._apollo_http_request("put", path, params=params, body=body)

    def delete(self, path, params={}):
        """
        Perform a DELETE request to the Apollo API.

        Args:
            path (str): API endpoint path.
            params (dict): Query parameters.

        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        """
        return self._apollo_http_request("delete", path, params=params)

    def _apollo_http_request(self, method, path, params={}, body={}):
        """
        Perform an HTTP request to the Apollo API.

        Args:
            method (str): HTTP method (get, post, patch, put, delete).
            path (str): API endpoint path.
            params (dict): Query parameters.
            body (dict): Request body.
            raw (bool): Flag indicating whether to return raw response or JSON.
        Returns:
            dict: Dictionary containing response information including headers, status code, and body.
        Raises:
            Exception: If an invalid HTTP method is provided.
        """
        available_http_method = ["get", "post", "patch", "put", "delete"]
        method = method.lower()
        apollo_api_key = self.api_key
        if method not in available_http_method:
            raise Exception(f"not available method {method}")
        request_method = getattr(requests, method)

        base_url = self.apollo_base_url
        url = base_url + ("/" + path if not path.startswith("/") else path)

        if method.lower() == "get":
            params["api_key"] = apollo_api_key
            response = request_method(url, params=params)
        else:
            body["api_key"] = apollo_api_key
            response = request_method(url, params=params, json=body)
        # return response
        result = {}
        result["headers"] = dict(response.headers)
        result["status_code"] = response.status_code
        try:
            result["body"] = response.json()
        except Exception:
            result["body"] = response.content
        return result
